@@ -4,12 +4,12 @@ use strict;
 use vars qw/$VERSION @ISA/;
 use DBIx::dbMan::Extension;
 
-$VERSION = '0.01';
+$VERSION = '0.02';
 @ISA = qw/DBIx::dbMan::Extension/;
 
 1;
 
-sub IDENTIFICATION { return "000001-000023-000001"; }
+sub IDENTIFICATION { return "000001-000023-000002"; }
 
 sub preference { return 1000; }
 
@@ -17,7 +17,7 @@ sub handle_action {
 	my ($obj,%action) = @_;
 
 	if ($action{action} eq 'COMMAND') {
-		if ($action{cmd} =~ /^\\i\s+(.*)$/i) {
+		if ($action{cmd} =~ /^(?:\\i\s+|\@)(.*)$/i) {
 			$action{action} = 'INPUT_FILE';
 			$action{file} = $1;
 		}
