@@ -4,12 +4,12 @@ use strict;
 use vars qw/$VERSION @ISA/;
 use DBIx::dbMan::Extension;
 
-$VERSION = '0.01';
+$VERSION = '0.02';
 @ISA = qw/DBIx::dbMan::Extension/;
 
 1;
 
-sub IDENTIFICATION { return "000001-000013-000001"; }
+sub IDENTIFICATION { return "000001-000013-000002"; }
 
 sub preference { return 1000; }
 
@@ -21,7 +21,7 @@ sub handle_action {
 			$action{action} = 'SQL';
 			$action{type} = 'select';
 			$action{sql} = $action{cmd};
-		} elsif ($action{cmd} =~ /^(delete|insert|update|create|drop|begin|alter)\s+/i) {
+		} elsif ($action{cmd} =~ /^((delete|insert|update|create|drop|begin|alter|truncate|grant|revoke)\s+.*|vacuum)$/i) {
 			$action{action} = 'SQL';
 			$action{type} = 'do';
 			$action{sql} = $action{cmd};
