@@ -5,12 +5,12 @@ use vars qw/$VERSION @ISA/;
 use DBIx::dbMan::Extension;
 use Text::FormatTable;
 
-$VERSION = '0.01';
+$VERSION = '0.02';
 @ISA = qw/DBIx::dbMan::Extension/;
 
 1;
 
-sub IDENTIFICATION { return "000001-000015-000001"; }
+sub IDENTIFICATION { return "000001-000015-000002"; }
 
 sub preference { return 0; }
 
@@ -25,7 +25,11 @@ sub handle_action {
 		} elsif ($action{type} eq 'do') {
 			if ($action{result} > -1) {
 				$action{action} = 'OUTPUT';
-				$action{output} = "Processed ".$action{result}." lines.\n" ;
+				if ($action{result} ne '0E0') {
+					$action{output} = "Processed ".$action{result}." line".(($action{result} == 1)?'':'s').".\n" ;
+				} else {
+					$action{output} = "Command processed.\n" ;
+				}
 			} else {
 				$action{action} = 'NONE';
 			}
